//+------------------------------------------------------------------+
//|                                                     CloseAll.mq4 |
//|                                    Copyright  2007, Petr Kouril |
//|                                           http://www.jaktrade.cz |
//+------------------------------------------------------------------+
#property copyright "Copyright  2007, Petr Kouril"
#property link      "http://www.jaktrade.cz"

// Revision 3

extern double		TopPrice       = 0;        // pokud je zadana tato hodnota TopDistance se ignoruje
extern double		BottomPrice    = 0;        // pokud je zadana tato hodnota BottomDistance se ignoruje
extern int        TopDistance    = 20;       // Vzdalenost v pipsech od aktualni ceny. TopPrice se spocita.
extern int        BottomDistance = 20;       // Vzdalenost v pipsech od aktualni ceny. BottomPrice se spocita.
extern int        Slippage       = 3;
extern color      LineColor      = Red;
extern color      LineColorDone  = DimGray;

extern bool       SendMailPossible =true;  
extern bool       AlertPossible    =true;               

string            StatusStr      = "EA active, revision 3";
bool					IsClose        = false;
double            Top, Bottom;
int               InitNum;

#define           TOP_NAME       "Top_Line"
#define           BOTTOM_NAME    "Bottom_Line"

int init()
{
   InitNum++;
   
   if (InitNum == 1)
   {
      if (TopPrice != 0)
         Top = TopPrice;
      else
         Top = Bid + TopDistance * Point;

      if (BottomPrice != 0)
         Bottom = BottomPrice;
      else
         Bottom = Bid - BottomDistance * Point;

      CreateLine(TOP_NAME,    Top);
      CreateLine(BOTTOM_NAME, Bottom);
   }
   EAComment();
   return(0);
}

int deinit()
{
   ObjectSet(TOP_NAME,    OBJPROP_COLOR, LineColorDone);
   ObjectSet(BOTTOM_NAME, OBJPROP_COLOR, LineColorDone);
//   ObjectDelete(TOP_NAME);
//   ObjectDelete(BOTTOM_NAME);
   return(0);
}

int start()
{
	double Price = Bid;
	string Notice;

   CheckLines();
   
	if ((Top < 0.01) || (Bottom <= 0.01))
	{
		StatusStr = "Error";
	}
	else
	{
		if ((Price >= Top) || (Price <= Bottom) || IsClose)
		{
			CloseAllOrders();

			if (!IsClose)
			{			
				if (Price >= Top)
				   Notice =  StringConcatenate(Symbol(), " SLPT Close on Top");
				else
				   Notice =  StringConcatenate(Symbol(), " SLPT Close on Bottom");

            if (SendMailPossible)				   
   			   SendMail("Forex", Notice);
				if (AlertPossible)	
				  {PlaySound("alert2.wav"); Alert(Notice);}

			}
			StatusStr = "Closed, need restart";		
			IsClose   = true;
		}
	}

   if (IsClose)		
   {
      ObjectSet(TOP_NAME,    OBJPROP_COLOR, LineColorDone);
      ObjectSet(BOTTOM_NAME, OBJPROP_COLOR, LineColorDone);
   }
   else
   {
      ObjectSet(TOP_NAME,    OBJPROP_COLOR, LineColor);
      ObjectSet(BOTTOM_NAME, OBJPROP_COLOR, LineColor);
   }
   
   EAComment();			  
   
   return(0);
}

void CreateLine(string Name, double Price)
{
   if (ObjectFind(Name) == -1)
      ObjectCreate(Name, OBJ_HLINE, 0, CurTime(), Price);
   else
      ObjectMove(Name, 0, CurTime(), Price);
      
   if (IsClose)
      ObjectSet(Name, OBJPROP_COLOR, LineColorDone);
   else   
      ObjectSet(Name, OBJPROP_COLOR, LineColor);
      
   ObjectSet   (Name, OBJPROP_STYLE, STYLE_DASHDOTDOT);
}

bool CloseAllOrders()
{
   int i;

   for(i = OrdersTotal(); i >= 0; i--) 
   {
      RefreshRates();
      OrderSelect(i, SELECT_BY_POS,MODE_TRADES);
      if (OrderSymbol() == Symbol())
      {
         if (OrderType() == OP_BUY)       {OrderClose(OrderTicket(), OrderLots(), Bid, Slippage, White);}
         if (OrderType() == OP_SELL)      {OrderClose(OrderTicket(), OrderLots(), Ask, Slippage, White);}
         if (OrderType() == OP_BUYLIMIT)  {OrderDelete(OrderTicket(), White);}
         if (OrderType() == OP_BUYSTOP)   {OrderDelete(OrderTicket(), White);}
         if (OrderType() == OP_SELLLIMIT) {OrderDelete(OrderTicket(), White);}
         if (OrderType() == OP_SELLSTOP)  {OrderDelete(OrderTicket(), White);}
      }
   }
   return (false);
}

void EAComment()
{
	string BottomStr, TopStr;
	
   if (IsClose)
   {
      BottomStr = "";
      TopStr    = "";
   }
   else
   {  
      TopStr    = StringConcatenate(", Distance: ", DoubleToStr((Top-Bid)    / Point, 0));
      BottomStr = StringConcatenate(", Distance: ", DoubleToStr((Bid-Bottom) / Point, 0));
   }
   
	Comment("Bid:       ", DoubleToStr(Bid,    Digits), "\n",
			  "Top:      " , DoubleToStr(Top,    Digits), TopStr,    "\n",
			  "Bottom: " ,   DoubleToStr(Bottom, Digits), BottomStr, "\n",
			  StatusStr, "\n");
}

/*
void CheckOpenOrders()
{
   int i;
   
   RefreshRates();
   TrueOpenOrders  = 0;
   for(i = OrdersTotal(); i >= 0; i--) 
   {
      RefreshRates();
      if (OrderSelect(i, SELECT_BY_POS,MODE_TRADES))
      {
         if ((OrderSymbol() == Symbol()) && (((OrderType() == OP_BUY)) || ((OrderType() == OP_SELL))))
         {
            TrueOpenOrders++;
         }
         if ((OrderSymbol() == Symbol()) && (((OrderType() == OP_BUYSTOP)) || ((OrderType() == OP_SELLSTOP))))
         {
            TrueOpenOrders++;
         }
      }
   }
}
*/

void CheckLines()
{
   double Value;   
   
   Value = ObjectGet(TOP_NAME, OBJPROP_PRICE1);
   if (GetLastError() == 0)
      Top = Value;

   Value = ObjectGet(BOTTOM_NAME, OBJPROP_PRICE1);
   if (GetLastError() == 0)
      Bottom = Value;
}

